Clojure only.

boundary.devtools.core.auto-fix

Fix descriptor registry — maps error codes to auto-fix descriptors. Pure functions — no I/O, no side effects.

Fix descriptors describe WHAT to fix, not HOW. The shell layer (boundary.devtools.shell.auto-fix) handles execution.

Fix descriptor registry — maps error codes to auto-fix descriptors.
Pure functions — no I/O, no side effects.

Fix descriptors describe WHAT to fix, not HOW. The shell layer
(boundary.devtools.shell.auto-fix) handles execution.
raw docstring

match-fixclj

(match-fix {:keys [code data]})

Find a fix descriptor for a classified error. Returns a fix descriptor map or nil if no fix is available.

The :data from the classified error is merged into :params so the executor has context about what to fix.

Find a fix descriptor for a classified error.
Returns a fix descriptor map or nil if no fix is available.

The :data from the classified error is merged into :params
so the executor has context about what to fix.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries