boundary.devtools.core.router

Pure functions for manipulating Reitit route data structures. All functions take and return route trees (vectors of [path handler-map]).

Pure functions for manipulating Reitit route data structures.
All functions take and return route trees (vectors of [path handler-map]).
raw docstring

add-routeclj

(add-route routes method path handler-fn)

Add a route to the route tree. If the path already exists, merges the method.

Add a route to the route tree. If the path already exists, merges the method.
sourceraw docstring

inject-tap-interceptorclj

(inject-tap-interceptor routes handler-name tap-fn)

Add a :devtools/tap interceptor to a handler's interceptor chain.

Add a :devtools/tap interceptor to a handler's interceptor chain.
sourceraw docstring

remove-routeclj

(remove-route routes method path)

Remove a method from a route. Removes the path entirely if it was the last method.

Remove a method from a route. Removes the path entirely if it was the last method.
sourceraw docstring

remove-tap-interceptorclj

(remove-tap-interceptor routes handler-name)

Remove the :devtools/tap interceptor from a handler's chain.

Remove the :devtools/tap interceptor from a handler's chain.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries