boundary.devtools.ports

Protocol definitions for the devtools library.

Protocol definitions for the devtools library.
raw docstring

IGuidancecljprotocol

Protocol for the guidance engine that provides contextual help.

Protocol for the guidance engine that provides contextual help.

guidance-levelclj

(guidance-level this)

Returns the current guidance level (:full, :minimal, :off).

Returns the current guidance level (:full, :minimal, :off).

set-guidance-level!clj

(set-guidance-level! this level)

Sets the guidance level at runtime.

Sets the guidance level at runtime.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries