boundary.devtools.shell.dashboard.pages.config

Dashboard page for configuration viewing and editing.

Dashboard page for configuration viewing and editing.
raw docstring

parse-edited-valueclj

(parse-edited-value new-val-str fallback)

Parse an edited textarea value back to a Clojure value, restoring ig/ref placeholders to real refs.

Parse an edited textarea value back to a Clojure value,
restoring ig/ref placeholders to real refs.
sourceraw docstring

renderclj

(render opts)

Render the Config Editor full page.

Render the Config Editor full page.
sourceraw docstring

render-apply-resultclj

(render-apply-result {:keys [success? restarted error]})

Render the result of a config apply operation as an HTML fragment.

Render the result of a config apply operation as an HTML fragment.
sourceraw docstring

render-preview-fragmentclj

(render-preview-fragment section-key old-val new-val-str)

Render a diff preview of proposed config change.

Render a diff preview of proposed config change.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries