Clojure only.

boundary.devtools.shell.dashboard.pages.docs

Module documentation viewer for the dev dashboard. Serves README.md and AGENTS.md from libs/<module>/.

Module documentation viewer for the dev dashboard.
Serves README.md and AGENTS.md from libs/<module>/.
raw docstring

renderclj

(render opts module-name filename)

Render the documentation viewer page for a specific module and file.

Render the documentation viewer page for a specific module and file.
sourceraw docstring

render-indexclj

(render-index opts)

Render the docs index page listing all modules with their available docs.

Render the docs index page listing all modules with their available docs.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries