boundary.devtools.shell.dashboard.pages.jobs

Dashboard page for Jobs & Queues monitoring.

Dashboard page for Jobs & Queues monitoring.
raw docstring

renderclj

(render opts)

Render the Jobs & Queues full page.

Render the Jobs & Queues full page.
sourceraw docstring

render-failed-jobs-fragmentclj

(render-failed-jobs-fragment opts)

Render only the failed jobs list as an HTML fragment for retry swap.

Render only the failed jobs list as an HTML fragment for retry swap.
sourceraw docstring

render-fragmentclj

(render-fragment opts)

Render the jobs content as an HTML fragment for HTMX polling.

Render the jobs content as an HTML fragment for HTMX polling.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries