boundary.devtools.shell.dashboard.pages.requests


renderclj

(render opts)

Render the Request Inspector full page with live HTMX polling.

Render the Request Inspector full page with live HTMX polling.
sourceraw docstring

render-detail-fragmentclj

(render-detail-fragment req)

Return request detail (headers, params) as an HTML fragment.

Return request detail (headers, params) as an HTML fragment.
sourceraw docstring

render-fragmentclj

(render-fragment req)

Return the request list as an HTML string fragment for HTMX polling.

Return the request list as an HTML string fragment for HTMX polling.
sourceraw docstring

render-request-listclj

(render-request-list & [filters])

Build a data-table from the current request log, newest first, limit 50.

Build a data-table from the current request log, newest first, limit 50.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries