boundary.devtools.shell.dashboard.pages.schemas


collect-schemasclj

(collect-schemas)

Collect available Malli schemas. Returns a seq of schema keys.

Collect available Malli schemas. Returns a seq of schema keys.
sourceraw docstring

renderclj

(render opts req)

Render the Schema Browser full page.

Render the Schema Browser full page.
sourceraw docstring

render-schema-detailclj

(render-schema-detail schema-key)

Render a schema's fields as a tree panel.

Render a schema's fields as a tree panel.
sourceraw docstring

reset-schemas!clj

(reset-schemas!)

Clear the cached schema map so it is re-discovered on next access. Called automatically on system reload.

Clear the cached schema map so it is re-discovered on next access.
Called automatically on system reload.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries