boundary.devtools.shell.dashboard.server

Integrant component for the dev dashboard HTTP server on port 9999.

Integrant component for the dev dashboard HTTP server on port 9999.
raw docstring

clear-config-overrides!clj

(clear-config-overrides!)

Reset dashboard config overrides so the next restart loads only on-disk config.

Reset dashboard config overrides so the next restart loads only on-disk config.
sourceraw docstring

config-overrides*clj

source

cljdoc builds & hosts documentation for Clojure/Script libraries