Pure functions for config diffing, dependency analysis, and formatting. FC/IS: no I/O, no logging.
Pure functions for config diffing, dependency analysis, and formatting. FC/IS: no I/O, no logging.
(affected-components diff)Given a config diff, return the set of component keys that would restart.
Given a config diff, return the set of component keys that would restart.
(config-diff old-config new-config)Compute diff between two config maps. Returns {:changed {key {:old v1 :new v2}} :added {key val} :removed {key val}}.
Compute diff between two config maps.
Returns {:changed {key {:old v1 :new v2}} :added {key val} :removed {key val}}.(contains-refs? v)Check if a config value contains any ig/ref instances.
Check if a config value contains any ig/ref instances.
(format-config-tree cfg)(format-config-tree cfg indent)Format a config map as an indented string tree for display.
Format a config map as an indented string tree for display.
(redact-secrets m)Recursively replace values of sensitive keys with "********".
Recursively replace values of sensitive keys with "********".
(restore-refs v)Restore :integrant.ref/* placeholders back to ig/ref values. Decodes the full qualified key preserved by strip-refs.
Restore :integrant.ref/* placeholders back to ig/ref values. Decodes the full qualified key preserved by strip-refs.
(strip-refs v)Replace ig/ref values with a keyword placeholder for serialization. Encodes the full qualified key (namespace + name) so restore-refs can round-trip refs with any namespace, not just :boundary/*.
Replace ig/ref values with a keyword placeholder for serialization. Encodes the full qualified key (namespace + name) so restore-refs can round-trip refs with any namespace, not just :boundary/*.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |