Pure functions for manipulating Reitit route data structures. All functions take and return route trees (vectors of [path handler-map]).
Pure functions for manipulating Reitit route data structures. All functions take and return route trees (vectors of [path handler-map]).
(add-route routes method path handler-fn)Add a route to the route tree. If the path already exists, merges the method.
Add a route to the route tree. If the path already exists, merges the method.
(inject-tap-interceptor routes handler-name tap-fn)Add a :devtools/tap interceptor to a handler's interceptor chain.
Add a :devtools/tap interceptor to a handler's interceptor chain.
(remove-route routes method path)Remove a method from a route. Removes the path entirely if it was the last method.
Remove a method from a route. Removes the path entirely if it was the last method.
(remove-tap-interceptor routes handler-name)Remove the :devtools/tap interceptor from a handler's chain.
Remove the :devtools/tap interceptor from a handler's chain.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |