Stack trace filtering and reordering for development error output. Pure functions — no I/O, no side effects.
Stack trace filtering and reordering for development error output. Pure functions — no I/O, no side effects.
(classify-frame ns-str)Classify a namespace string as :user, :framework, or :jvm.
Classify a namespace string as :user, :framework, or :jvm.
(filter-stacktrace exception)Filter and reorder an exception's stack trace. Returns {:user-frames [...] :framework-frames [...] :jvm-frames [...] :total-hidden N}
Filter and reorder an exception's stack trace.
Returns {:user-frames [...] :framework-frames [...] :jvm-frames [...] :total-hidden N}(format-stacktrace {:keys [user-frames total-hidden]})Format a filtered stack trace for display.
Format a filtered stack trace for display.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |