Protocol definitions for the devtools library.
Protocol definitions for the devtools library.
Protocol for the guidance engine that provides contextual help.
Protocol for the guidance engine that provides contextual help.
(guidance-level this)Returns the current guidance level (:full, :minimal, :off).
Returns the current guidance level (:full, :minimal, :off).
(set-guidance-level! this level)Sets the guidance level at runtime.
Sets the guidance level at runtime.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |