Dashboard page for configuration viewing and editing.
Dashboard page for configuration viewing and editing.
(parse-edited-value new-val-str fallback)Parse an edited textarea value back to a Clojure value, restoring ig/ref placeholders to real refs.
Parse an edited textarea value back to a Clojure value, restoring ig/ref placeholders to real refs.
(render opts)Render the Config Editor full page.
Render the Config Editor full page.
(render-apply-result {:keys [success? restarted error]})Render the result of a config apply operation as an HTML fragment.
Render the result of a config apply operation as an HTML fragment.
(render-preview-fragment section-key old-val new-val-str)Render a diff preview of proposed config change.
Render a diff preview of proposed config change.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |