Module documentation viewer for the dev dashboard. Serves README.md and AGENTS.md from libs/<module>/.
Module documentation viewer for the dev dashboard. Serves README.md and AGENTS.md from libs/<module>/.
(render opts module-name filename)Render the documentation viewer page for a specific module and file.
Render the documentation viewer page for a specific module and file.
(render-index opts)Render the docs index page listing all modules with their available docs.
Render the docs index page listing all modules with their available docs.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |