Dashboard page for Jobs & Queues monitoring.
Dashboard page for Jobs & Queues monitoring.
(render opts)Render the Jobs & Queues full page.
Render the Jobs & Queues full page.
(render-failed-jobs-fragment opts)Render only the failed jobs list as an HTML fragment for retry swap.
Render only the failed jobs list as an HTML fragment for retry swap.
(render-fragment opts)Render the jobs content as an HTML fragment for HTMX polling.
Render the jobs content as an HTML fragment for HTMX polling.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |