(render opts)Render the Request Inspector full page with live HTMX polling.
Render the Request Inspector full page with live HTMX polling.
(render-detail-fragment req)Return request detail (headers, params) as an HTML fragment.
Return request detail (headers, params) as an HTML fragment.
(render-fragment req)Return the request list as an HTML string fragment for HTMX polling.
Return the request list as an HTML string fragment for HTMX polling.
(render-request-list & [filters])Build a data-table from the current request log, newest first, limit 50.
Build a data-table from the current request log, newest first, limit 50.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |