(collect-schemas)Collect available Malli schemas. Returns a seq of schema keys.
Collect available Malli schemas. Returns a seq of schema keys.
(render opts req)Render the Schema Browser full page.
Render the Schema Browser full page.
(render-schema-detail schema-key)Render a schema's fields as a tree panel.
Render a schema's fields as a tree panel.
(reset-schemas!)Clear the cached schema map so it is re-discovered on next access. Called automatically on system reload.
Clear the cached schema map so it is re-discovered on next access. Called automatically on system reload.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |