Integrant component for the dev dashboard HTTP server on port 9999.
Integrant component for the dev dashboard HTTP server on port 9999.
(clear-config-overrides!)Reset dashboard config overrides so the next restart loads only on-disk config.
Reset dashboard config overrides so the next restart loads only on-disk config.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |