Dev-mode HTTP error enrichment middleware. Positioned INSIDE wrap-enhanced-exception-handling. Catches exceptions, runs the error pipeline, and re-throws with :dev-info attached to ex-data so the outer middleware can include it in the RFC 7807 response.
Dev-mode HTTP error enrichment middleware. Positioned INSIDE wrap-enhanced-exception-handling. Catches exceptions, runs the error pipeline, and re-throws with :dev-info attached to ex-data so the outer middleware can include it in the RFC 7807 response.
(wrap-dev-error-enrichment handler)Ring middleware that enriches exceptions with dev-info in dev mode. Catches exceptions, runs the error pipeline, attaches result as :dev-info in the exception's ex-data, and re-throws. The outer error handling middleware can then include :dev-info in its Problem Details response.
Ring middleware that enriches exceptions with dev-info in dev mode. Catches exceptions, runs the error pipeline, attaches result as :dev-info in the exception's ex-data, and re-throws. The outer error handling middleware can then include :dev-info in its Problem Details response.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |